from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String, Int, File

Gff3Togenepred_V0_1_0 = CommandToolBuilder(tool="gff3ToGenePred", base_command=["gff3ToGenePred"], inputs=[ToolInput(tag="in_warn_and_continue", input_type=Boolean(optional=True), prefix="-warnAndContinue", doc=InputDocumentation(doc="- on bad genePreds being created, put out warning but continue")), ToolInput(tag="in_use_name", input_type=Boolean(optional=True), prefix="-useName", doc=InputDocumentation(doc="- rather than using 'id' as name, use the 'name' tag")), ToolInput(tag="in_rna_name_attr", input_type=String(optional=True), prefix="-rnaNameAttr", doc=InputDocumentation(doc="- If this attribute exists on an RNA record, use it as the genePred\nname column")), ToolInput(tag="in_gene_name_attr", input_type=Int(optional=True), prefix="-geneNameAttr", doc=InputDocumentation(doc="- If this attribute exists on a gene record, use it as the genePred\nname2 column")), ToolInput(tag="in_attrs_out", input_type=File(optional=True), prefix="-attrsOut", doc=InputDocumentation(doc="- output attributes of mRNA record to file.  These are per-genePred row,\nnot per-GFF3 record. Thery are derived from GFF3 attributes, not the attributes themselves.")), ToolInput(tag="in_process_all_gene_children", input_type=Boolean(optional=True), prefix="-processAllGeneChildren", doc=InputDocumentation(doc="- output genePred for all children of a gene regardless of feature")), ToolInput(tag="in_unprocessed_roots_out", input_type=File(optional=True), prefix="-unprocessedRootsOut", doc=InputDocumentation(doc="- output GFF3 root records that were not used.  This will not be a\nvalid GFF3 file.  It's expected that many non-root records will not be used and they are not\nreported.")), ToolInput(tag="in_bad", input_type=File(optional=True), prefix="-bad", doc=InputDocumentation(doc="- output genepreds that fail checks to file")), ToolInput(tag="in_max_parse_error_s", input_type=Int(optional=True), prefix="-maxParseErrors", doc=InputDocumentation(doc="- Maximum number of parsing errors before aborting. A negative\nvalue will allow an unlimited number of errors.  Default is 50.")), ToolInput(tag="in_max_convert_errors", input_type=Int(optional=True), prefix="-maxConvertErrors", doc=InputDocumentation(doc="- Maximum number of conversion errors before aborting. A negative\nvalue will allow an unlimited number of errors.  Default is 50.")), ToolInput(tag="in_honor_start_stop_codons", input_type=Boolean(optional=True), prefix="-honorStartStopCodons", doc=InputDocumentation(doc="- only set CDS start/stop status to complete if there are\ncorresponding start_stop codon records")), ToolInput(tag="in_default_cds_status_to_unknown", input_type=Boolean(optional=True), prefix="-defaultCdsStatusToUnknown", doc=InputDocumentation(doc="- default the CDS status to unknown rather\nthan complete.")), ToolInput(tag="in_allow_minimal_genes", input_type=Boolean(optional=True), prefix="-allowMinimalGenes", doc=InputDocumentation(doc="- normally this programs assumes that genes contains\ntranscripts which contain exons.  If this option is specified, genes with exons\nas direct children of genes and stand alone genes with no exon or transcript\nchildren will be converted.")), ToolInput(tag="in_refseq_hacks", input_type=Boolean(optional=True), prefix="-refseqHacks", doc=InputDocumentation(doc="- enable various hacks to make RefSeq conversion work:\nThis turns on -useName, -allowMinimalGenes, and -processAllGeneChildren.\nIt try harder to find an accession in attributes")), ToolInput(tag="in_in_gff_three", input_type=Int(), position=0, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_attrs_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_attrs_out", type_hint=File()), doc=OutputDocumentation(doc="- output attributes of mRNA record to file.  These are per-genePred row,\nnot per-GFF3 record. Thery are derived from GFF3 attributes, not the attributes themselves.")), ToolOutput(tag="out_unprocessed_roots_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_unprocessed_roots_out", type_hint=File()), doc=OutputDocumentation(doc="- output GFF3 root records that were not used.  This will not be a\nvalid GFF3 file.  It's expected that many non-root records will not be used and they are not\nreported.")), ToolOutput(tag="out_bad", output_type=File(optional=True), selector=InputSelector(input_to_select="in_bad", type_hint=File()), doc=OutputDocumentation(doc="- output genepreds that fail checks to file"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gff3Togenepred_V0_1_0().translate("wdl", allow_empty_container=True)

